==> qtjambi-opengl-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiOpenGL/QOpenGLShader_shell.h <==
#ifndef QOPENGLSHADER_SHELL_H
#define QOPENGLSHADER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtOpenGL/qopenglshaderprogram.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qopenglcontext.h>
#include <QtJambi/RegistryAPI>


class QOpenGLShader_shell : public QOpenGLShader, public QtJambiShellInterface
{
public:
    QOpenGLShader_shell(QOpenGLShader::ShaderType type0, QObject* parent1 = nullptr);
    ~QOpenGLShader_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QOpenGLShader_access : public QOpenGLShader
{
};

#endif // QOPENGLSHADER_SHELL_H

==> qtjambi-opengl-debuginfo-windows-x64-6.5.8.jar: sources/QtJambiOpenGL/QOpenGLShader_shell.h <==
#ifndef QOPENGLSHADER_SHELL_H
#define QOPENGLSHADER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtOpenGL/qopenglshaderprogram.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qopenglcontext.h>
#include <QtJambi/RegistryAPI>


class QOpenGLShader_shell : public QOpenGLShader, public QtJambiShellInterface
{
public:
    QOpenGLShader_shell(QOpenGLShader::ShaderType type0, QObject* parent1 = nullptr);
    ~QOpenGLShader_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QOpenGLShader_mshell;
    friend class QOpenGLShader_oshell;
};


class QOpenGLShader_mshell : public QOpenGLShader_shell
{
public:
    using QOpenGLShader_shell::QOpenGLShader_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QOpenGLShader_oshell : public QOpenGLShader_mshell
{
public:
    using QOpenGLShader_mshell::QOpenGLShader_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QOpenGLShader_access : public QOpenGLShader
{
};

#endif // QOPENGLSHADER_SHELL_H
